@@ -1,7 +1,8 @@
+import os
 from tackle import tackle
 
 
 def test_docs_build(change_dir_base):
     """Make sure docs build."""
-    output = tackle('docs/docs-gen.yaml', no_input=True)
+    output = tackle(os.path.join('docs', 'docs-gen.yaml'), no_input=True)
     assert output
